@@ -2,11 +2,10 @@ from datetime import datetime
 from math import ceil
 from typing import Any, Optional
 from uuid import uuid4
-
-from dateutil.tz import gettz
+from zoneinfo import ZoneInfo
 
 from .age import AgeValueError, age, formatted_age, get_age_in_days, get_dob
-from .date import get_utcnow, get_utcnow_as_date, to_arrow_utc, to_utc
+from .date import get_utcnow, get_utcnow_as_date, to_utc
 from .disable_signals import DisableSignals
 from .get_static_file import get_static_file
 from .show_urls import show_url_names, show_urls
@@ -54,5 +53,5 @@ def get_datetime_from_env(
         int(minute),
         int(second),
         0,
-        gettz(time_zone),
+        ZoneInfo(time_zone),
     )
